@@ -34,7 +34,7 @@ const SCROLLING_ANIMATION_TIME = 400000; //us
 var WeatherWidget = new Lang.Class({
     Name: 'WeatherWidget',
     Extends: Gtk.Frame,
-    Template: 'resource:///org/gnome/Weather/Application/weather-widget.ui',
+    Template: 'resource:///org/gnome/Weather/weather-widget.ui',
     InternalChildren: ['contentFrame', 'outerGrid', 'conditionsImage',
                        'temperatureLabel', 'conditionsLabel',
                        'timeLabel', 'timeGrid', 'forecastStack',
@@ -188,6 +188,10 @@ var WeatherWidget = new Lang.Class({
         for (let t of ['today', 'tomorrow'])
             this._forecasts[t].update(forecasts, t);
 
+        if (!this._forecasts['today'].hasForecastInfo() && this._forecasts['tomorrow'].hasForecastInfo())
+            this._forecastStack.set_visible_child_name('tomorrow');
+
+        // FIXME: This doesn't make sense, since the above code assumes forecasts.length != 0.
         if (forecasts.length == 0) {
             this._weeklyForecasts.hide();
         } else {
@@ -200,7 +204,7 @@ var WeatherWidget = new Lang.Class({
 var WeatherView = new Lang.Class({
     Name: 'WeatherView',
     Extends: Gtk.Stack,
-    Template: 'resource:///org/gnome/Weather/Application/city.ui',
+    Template: 'resource:///org/gnome/Weather/city.ui',
     InternalChildren: ['spinner'],
 
     _init: function(params) {
